type token =
  | IDENTIFIER of (string)
  | STRING_LITERAL of (string)
  | TYPENAME of (string)
  | CONSTANT of (Clogic.constant)
  | LPAR
  | RPAR
  | IF
  | ELSE
  | COLON
  | COLONCOLON
  | DOT
  | DOTDOT
  | AMP
  | INT
  | FLOAT
  | LT
  | GT
  | LE
  | GE
  | EQ
  | NE
  | COMMA
  | ARROW
  | EQUAL
  | FORALL
  | EXISTS
  | IFF
  | IMPLIES
  | AND
  | OR
  | NOT
  | TRUE
  | FALSE
  | OLD
  | AT
  | RESULT
  | BLOCK_LENGTH
  | BASE_ADDR
  | OFFSET
  | SEPARATED
  | FULLSEPARATED
  | VALID
  | VALID_INDEX
  | VALID_RANGE
  | FRESH
  | THEN
  | QUESTION
  | MINUS
  | PLUS
  | STAR
  | SLASH
  | PERCENT
  | LSQUARE
  | RSQUARE
  | EOF
  | INVARIANT
  | VARIANT
  | DECREASES
  | FOR
  | LABEL
  | ASSERT
  | SEMICOLON
  | NULL
  | REQUIRES
  | ENSURES
  | ASSIGNS
  | LOOP_ASSIGNS
  | NOTHING
  | READS
  | LOGIC
  | PREDICATE
  | AXIOM
  | LBRACE
  | RBRACE
  | GHOST
  | SET
  | VOID
  | CHAR
  | SIGNED
  | UNSIGNED
  | SHORT
  | LONG
  | DOUBLE
  | STRUCT
  | ENUM
  | UNION
  | TYPE

open Parsing;;
# 20 "c/clparser.mly"
  open Ctypes
  open Cast
  open Clogic

  let loc () = (Loc.reloc (symbol_start_pos ()), Loc.reloc (symbol_end_pos ()))
  let loc_i i = (rhs_start_pos i, rhs_end_pos i)
  let info x = { Clogic.lexpr_node = x; lexpr_loc = loc () }

  type ghost_decl =
    | Dsimple 
    | Darray of ghost_decl * lexpr option

  let rec expr_of_lexpr e =
    match e.lexpr_node with
      | PLconstant c -> 
	  { Cast.node = Cast.CEconstant c ; Cast.loc = e.lexpr_loc }
      | _ -> Creport.error e.lexpr_loc "not a constant"

  let option_app f = function None -> None | Some x -> Some (f x)

  let rec ghost_type ty gd =
    match gd with
      | Dsimple -> ty
      | Darray(gd,size) -> 
	    Cast_misc.noattr 
	      (Cast.CTarray (ghost_type ty gd, option_app expr_of_lexpr size))

  let ghost ty (id,gd,cinit) =
    let gty = ghost_type ty gd in
    LDghost(gty,id,cinit)
    
    
# 125 "c/clparser.ml"
let yytransl_const = [|
  261 (* LPAR *);
  262 (* RPAR *);
  263 (* IF *);
  264 (* ELSE *);
  265 (* COLON *);
  266 (* COLONCOLON *);
  267 (* DOT *);
  268 (* DOTDOT *);
  269 (* AMP *);
  270 (* INT *);
  271 (* FLOAT *);
  272 (* LT *);
  273 (* GT *);
  274 (* LE *);
  275 (* GE *);
  276 (* EQ *);
  277 (* NE *);
  278 (* COMMA *);
  279 (* ARROW *);
  280 (* EQUAL *);
  281 (* FORALL *);
  282 (* EXISTS *);
  283 (* IFF *);
  284 (* IMPLIES *);
  285 (* AND *);
  286 (* OR *);
  287 (* NOT *);
  288 (* TRUE *);
  289 (* FALSE *);
  290 (* OLD *);
  291 (* AT *);
  292 (* RESULT *);
  293 (* BLOCK_LENGTH *);
  294 (* BASE_ADDR *);
  295 (* OFFSET *);
  296 (* SEPARATED *);
  297 (* FULLSEPARATED *);
  298 (* VALID *);
  299 (* VALID_INDEX *);
  300 (* VALID_RANGE *);
  301 (* FRESH *);
  302 (* THEN *);
  303 (* QUESTION *);
  304 (* MINUS *);
  305 (* PLUS *);
  306 (* STAR *);
  307 (* SLASH *);
  308 (* PERCENT *);
  309 (* LSQUARE *);
  310 (* RSQUARE *);
    0 (* EOF *);
  311 (* INVARIANT *);
  312 (* VARIANT *);
  313 (* DECREASES *);
  314 (* FOR *);
  315 (* LABEL *);
  316 (* ASSERT *);
  317 (* SEMICOLON *);
  318 (* NULL *);
  319 (* REQUIRES *);
  320 (* ENSURES *);
  321 (* ASSIGNS *);
  322 (* LOOP_ASSIGNS *);
  323 (* NOTHING *);
  324 (* READS *);
  325 (* LOGIC *);
  326 (* PREDICATE *);
  327 (* AXIOM *);
  328 (* LBRACE *);
  329 (* RBRACE *);
  330 (* GHOST *);
  331 (* SET *);
  332 (* VOID *);
  333 (* CHAR *);
  334 (* SIGNED *);
  335 (* UNSIGNED *);
  336 (* SHORT *);
  337 (* LONG *);
  338 (* DOUBLE *);
  339 (* STRUCT *);
  340 (* ENUM *);
  341 (* UNION *);
  342 (* TYPE *);
    0|]

let yytransl_block = [|
  257 (* IDENTIFIER *);
  258 (* STRING_LITERAL *);
  259 (* TYPENAME *);
  260 (* CONSTANT *);
    0|]

let yylhs = "\255\255\
\002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
\002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
\002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
\002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
\002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
\002\000\002\000\002\000\002\000\002\000\005\000\005\000\008\000\
\008\000\008\000\007\000\007\000\007\000\007\000\007\000\007\000\
\007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
\007\000\007\000\007\000\007\000\007\000\007\000\007\000\009\000\
\009\000\003\000\003\000\003\000\003\000\003\000\003\000\006\000\
\006\000\010\000\010\000\011\000\011\000\012\000\012\000\013\000\
\016\000\016\000\016\000\016\000\017\000\019\000\019\000\015\000\
\015\000\001\000\021\000\021\000\021\000\021\000\021\000\021\000\
\021\000\024\000\014\000\014\000\014\000\018\000\018\000\020\000\
\020\000\025\000\025\000\026\000\022\000\022\000\022\000\022\000\
\022\000\022\000\022\000\022\000\022\000\023\000\028\000\028\000\
\028\000\028\000\027\000\027\000\004\000\004\000\030\000\030\000\
\029\000\029\000\031\000\031\000\032\000\034\000\034\000\034\000\
\033\000\033\000\033\000\035\000\035\000\000\000"

let yylen = "\002\000\
\003\000\003\000\003\000\003\000\002\000\001\000\001\000\003\000\
\006\000\004\000\004\000\006\000\006\000\004\000\006\000\008\000\
\004\000\001\000\001\000\003\000\003\000\003\000\003\000\003\000\
\003\000\003\000\004\000\006\000\002\000\002\000\002\000\002\000\
\005\000\004\000\006\000\004\000\004\000\004\000\001\000\003\000\
\001\000\004\000\004\000\004\000\003\000\000\000\001\000\001\000\
\002\000\001\000\001\000\001\000\002\000\002\000\002\000\001\000\
\002\000\002\000\001\000\002\000\002\000\001\000\002\000\003\000\
\002\000\003\000\001\000\001\000\002\000\001\000\002\000\001\000\
\002\000\001\000\001\000\001\000\001\000\001\000\001\000\000\000\
\001\000\001\000\003\000\000\000\002\000\000\000\002\000\004\000\
\003\000\002\000\002\000\001\000\002\000\004\000\002\000\000\000\
\002\000\002\000\001\000\001\000\001\000\001\000\002\000\002\000\
\004\000\001\000\000\000\002\000\002\000\000\000\001\000\002\000\
\002\000\001\000\003\000\001\000\006\000\008\000\009\000\005\000\
\007\000\008\000\004\000\004\000\002\000\003\000\001\000\001\000\
\001\000\001\000\000\000\001\000\001\000\003\000\002\000\004\000\
\001\000\003\000\001\000\003\000\001\000\001\000\004\000\003\000\
\001\000\003\000\004\000\001\000\003\000\002\000"

let yydefred = "\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\150\000\000\000\101\000\
\102\000\000\000\000\000\000\000\000\000\099\000\100\000\000\000\
\019\000\000\000\000\000\000\000\000\000\000\000\000\000\006\000\
\007\000\000\000\000\000\039\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\018\000\000\000\104\000\000\000\000\000\000\000\113\000\000\000\
\112\000\000\000\000\000\070\000\056\000\067\000\051\000\052\000\
\000\000\000\000\059\000\000\000\068\000\000\000\000\000\000\000\
\000\000\128\000\129\000\127\000\130\000\000\000\000\000\000\000\
\125\000\000\000\000\000\000\000\111\000\000\000\090\000\098\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\074\000\075\000\076\000\077\000\078\000\
\079\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\072\000\
\000\000\055\000\053\000\058\000\000\000\057\000\054\000\060\000\
\000\000\065\000\069\000\071\000\000\000\000\000\000\000\142\000\
\000\000\137\000\000\000\000\000\000\000\109\000\108\000\000\000\
\000\000\089\000\000\000\000\000\000\000\081\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\026\000\025\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\115\000\073\000\064\000\066\000\000\000\132\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\088\000\
\000\000\000\000\042\000\000\000\000\000\000\000\000\000\000\000\
\134\000\000\000\034\000\000\000\038\000\036\000\037\000\000\000\
\000\000\014\000\000\000\000\000\017\000\000\000\027\000\000\000\
\000\000\000\000\138\000\000\000\000\000\140\000\144\000\000\000\
\097\000\094\000\083\000\000\000\136\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\148\000\000\000\143\000\000\000\035\000\012\000\013\000\015\000\
\000\000\028\000\000\000\000\000\121\000\000\000\000\000\146\000\
\000\000\118\000\000\000\122\000\147\000\149\000\016\000\119\000"

let yydgoto = "\002\000\
\014\000\056\000\134\000\207\000\200\000\165\000\070\000\097\000\
\137\000\166\000\015\000\161\000\016\000\083\000\216\000\017\000\
\018\000\019\000\087\000\020\000\021\000\022\000\023\000\080\000\
\057\000\058\000\208\000\078\000\153\000\098\000\154\000\155\000\
\246\000\156\000\010\001"

let yysindex = "\024\000\
\166\010\000\000\165\006\035\255\215\006\215\006\017\005\031\255\
\038\255\040\255\001\255\215\006\041\255\000\000\240\254\000\000\
\000\000\237\254\000\255\000\000\060\000\000\000\000\000\018\255\
\000\000\054\255\215\006\215\006\031\255\031\255\215\006\000\000\
\000\000\057\255\058\255\000\000\060\255\072\255\076\255\077\255\
\101\255\114\255\124\255\132\255\134\255\215\006\215\006\215\006\
\000\000\152\010\000\000\019\255\152\010\152\010\000\000\152\010\
\000\000\119\255\092\255\000\000\000\000\000\000\000\000\000\000\
\251\254\037\255\000\000\205\254\000\000\093\255\143\255\140\255\
\137\255\000\000\000\000\000\000\000\000\146\255\152\010\126\255\
\000\000\234\005\084\255\000\255\000\000\215\006\000\000\000\000\
\215\006\215\006\215\006\204\255\034\255\176\009\117\255\098\255\
\159\255\139\255\102\255\104\255\215\006\215\006\215\006\215\006\
\215\006\215\006\215\006\215\006\215\006\215\006\215\006\117\255\
\117\255\117\255\161\255\000\000\000\000\000\000\000\000\000\000\
\000\000\163\255\215\006\215\006\215\006\215\006\215\006\215\006\
\215\006\215\006\215\006\215\006\215\006\215\006\215\006\000\000\
\116\255\000\000\000\000\000\000\086\255\000\000\000\000\000\000\
\091\255\000\000\000\000\000\000\168\255\031\255\215\006\000\000\
\152\255\000\000\151\255\123\255\215\006\000\000\000\000\215\006\
\121\255\000\000\045\007\191\009\173\255\000\000\152\010\152\010\
\009\007\215\006\215\006\215\006\127\255\031\255\215\006\093\007\
\234\009\141\007\189\007\237\007\249\009\036\010\029\008\051\010\
\094\010\077\008\000\000\000\000\152\010\152\010\104\255\167\010\
\074\009\116\000\116\000\117\255\117\255\117\255\117\009\170\255\
\247\255\000\000\000\000\000\000\000\000\031\255\000\000\177\255\
\152\010\146\255\133\005\114\006\152\010\152\010\000\255\000\000\
\183\255\215\006\000\000\117\255\117\255\059\009\152\010\131\255\
\000\000\152\010\000\000\185\255\000\000\000\000\000\000\215\006\
\215\006\000\000\215\006\215\006\000\000\215\006\000\000\215\006\
\181\255\236\254\000\000\133\005\152\010\000\000\000\000\132\009\
\000\000\000\000\000\000\215\006\000\000\186\255\125\008\173\008\
\221\008\109\010\104\255\152\010\157\255\238\254\215\006\215\006\
\000\000\254\254\000\000\104\255\000\000\000\000\000\000\000\000\
\215\006\000\000\215\006\215\006\000\000\014\006\164\255\000\000\
\013\009\000\000\061\006\000\000\000\000\000\000\000\000\000\000"

let yyrindex = "\000\000\
\033\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\044\000\000\000\
\000\000\008\000\000\000\012\000\000\000\000\000\000\000\210\004\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\005\000\000\000\001\000\191\000\038\000\000\000\101\000\
\000\000\043\000\193\255\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\016\255\000\000\215\255\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\194\255\000\000\
\000\000\000\000\003\000\217\000\000\000\000\000\000\000\000\000\
\213\255\000\000\000\000\000\000\000\000\000\000\126\000\000\000\
\000\000\012\255\000\000\104\003\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\188\000\
\250\000\056\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\216\255\000\000\000\000\000\000\
\228\255\000\000\000\000\000\000\020\255\000\000\000\000\000\000\
\099\255\000\000\000\000\000\000\000\000\224\255\000\000\000\000\
\235\000\000\000\011\000\010\000\000\000\000\000\000\000\000\000\
\238\000\000\000\239\000\234\255\000\000\000\000\241\000\143\003\
\064\000\000\000\000\000\000\000\013\255\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\012\004\074\004\166\003\097\004\
\000\000\174\002\236\002\119\001\181\001\243\001\230\255\000\000\
\042\003\000\000\000\000\000\000\000\000\224\255\000\000\000\000\
\243\000\000\000\000\000\000\000\244\000\006\000\000\000\000\000\
\000\000\000\000\000\000\049\002\111\002\000\000\136\004\000\000\
\000\000\159\004\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\191\255\
\000\000\246\000\000\000\000\000\004\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\229\003\195\255\000\000\247\000\000\000\000\000\
\000\000\000\000\000\000\035\004\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"

let yygindex = "\000\000\
\000\000\241\005\000\000\240\255\019\000\000\000\222\000\252\000\
\000\000\046\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\249\000\179\255\253\000\000\000\000\000\000\000\000\000\
\174\255\000\000\055\000\000\000\000\000\000\000\052\000\000\000\
\014\255\000\000\000\000"

let yytablesize = 3068
let yytable = "\159\000\
\041\000\009\001\086\000\145\000\093\000\087\000\162\000\110\000\
\138\000\141\000\139\000\092\000\096\000\099\000\074\000\075\000\
\062\000\133\000\135\000\023\001\061\000\062\000\089\000\089\000\
\001\000\061\000\090\000\091\000\091\000\146\000\147\000\059\000\
\084\000\060\000\135\000\051\000\030\001\085\000\072\000\170\000\
\073\000\081\000\114\000\107\000\061\000\062\000\007\000\007\001\
\082\000\019\001\142\000\008\001\202\000\020\001\052\000\086\000\
\060\000\025\000\026\000\088\000\027\000\101\000\102\000\040\000\
\103\000\062\000\028\000\061\000\062\000\061\000\024\001\139\000\
\133\000\135\000\140\000\141\000\104\000\076\000\029\000\030\000\
\105\000\106\000\077\000\148\000\031\000\032\000\033\000\034\000\
\035\000\036\000\037\000\038\000\039\000\040\000\041\000\042\000\
\043\000\044\000\045\000\063\000\116\000\046\000\047\000\048\000\
\063\000\107\000\063\000\064\000\065\000\066\000\067\000\068\000\
\069\000\143\000\115\000\049\000\144\000\145\000\108\000\116\000\
\117\000\118\000\119\000\120\000\121\000\032\000\122\000\115\000\
\109\000\063\000\064\000\065\000\066\000\067\000\068\000\069\000\
\110\000\249\000\111\000\122\000\135\000\136\000\148\000\149\000\
\150\000\151\000\152\000\160\000\063\000\157\000\127\000\128\000\
\129\000\130\000\131\000\132\000\133\000\225\000\172\000\173\000\
\174\000\187\000\175\000\188\000\052\000\203\000\204\000\025\000\
\026\000\133\000\027\000\205\000\206\000\210\000\211\000\212\000\
\028\000\215\000\219\000\224\000\021\001\240\000\242\000\250\000\
\253\000\254\000\006\001\029\000\029\000\030\000\103\000\013\001\
\026\001\048\000\031\000\032\000\033\000\034\000\035\000\036\000\
\037\000\038\000\039\000\040\000\041\000\042\000\043\000\044\000\
\045\000\169\000\018\001\046\000\047\000\048\000\115\000\050\000\
\091\000\106\000\080\000\116\000\117\000\118\000\119\000\120\000\
\121\000\049\000\122\000\046\000\049\000\131\000\123\000\124\000\
\125\000\126\000\126\000\244\000\029\001\096\000\095\000\082\000\
\124\000\047\000\123\000\105\000\046\000\120\000\117\000\093\000\
\047\000\030\000\127\000\128\000\129\000\130\000\131\000\132\000\
\133\000\115\000\005\001\071\000\241\000\243\000\041\000\251\000\
\041\000\041\000\084\000\041\000\041\000\122\000\085\000\000\000\
\041\000\041\000\041\000\041\000\041\000\041\000\041\000\041\000\
\041\000\145\000\000\000\041\000\041\000\041\000\041\000\141\000\
\139\000\141\000\000\000\000\000\000\000\000\000\128\000\129\000\
\130\000\131\000\132\000\133\000\000\000\000\000\041\000\041\000\
\041\000\041\000\041\000\041\000\041\000\041\000\041\000\031\000\
\041\000\041\000\041\000\086\000\093\000\000\000\087\000\110\000\
\041\000\041\000\041\000\111\000\000\000\040\000\093\000\040\000\
\040\000\041\000\040\000\040\000\145\000\000\000\000\000\040\000\
\040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
\110\000\084\000\040\000\040\000\040\000\040\000\085\000\000\000\
\084\000\084\000\114\000\114\000\107\000\085\000\085\000\000\000\
\000\000\000\000\114\000\107\000\000\000\040\000\040\000\040\000\
\040\000\040\000\040\000\040\000\040\000\040\000\022\000\040\000\
\040\000\040\000\116\000\000\000\000\000\000\000\115\000\040\000\
\040\000\040\000\000\000\032\000\000\000\032\000\032\000\000\000\
\040\000\032\000\122\000\000\000\000\000\032\000\032\000\032\000\
\032\000\032\000\032\000\032\000\000\000\032\000\000\000\000\000\
\032\000\032\000\032\000\032\000\116\000\116\000\000\000\000\000\
\000\000\000\000\000\000\000\000\116\000\130\000\131\000\132\000\
\133\000\000\000\000\000\032\000\032\000\032\000\032\000\032\000\
\032\000\032\000\000\000\032\000\023\000\032\000\032\000\032\000\
\000\000\000\000\000\000\000\000\000\000\032\000\032\000\032\000\
\000\000\029\000\000\000\029\000\029\000\000\000\032\000\029\000\
\000\000\000\000\000\000\029\000\029\000\029\000\029\000\029\000\
\029\000\029\000\000\000\029\000\000\000\000\000\029\000\029\000\
\029\000\029\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\029\000\029\000\029\000\029\000\029\000\029\000\029\000\
\000\000\029\000\024\000\029\000\029\000\029\000\000\000\000\000\
\000\000\000\000\000\000\029\000\029\000\029\000\000\000\030\000\
\000\000\030\000\030\000\000\000\029\000\030\000\000\000\000\000\
\000\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
\000\000\030\000\000\000\000\000\030\000\030\000\030\000\030\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\030\000\
\030\000\030\000\030\000\030\000\030\000\030\000\000\000\030\000\
\044\000\030\000\030\000\030\000\000\000\000\000\000\000\000\000\
\000\000\030\000\030\000\030\000\000\000\031\000\000\000\031\000\
\031\000\000\000\030\000\031\000\000\000\000\000\000\000\031\000\
\031\000\031\000\031\000\031\000\031\000\031\000\000\000\031\000\
\000\000\000\000\031\000\031\000\031\000\031\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\031\000\031\000\031\000\
\031\000\031\000\031\000\031\000\000\000\031\000\043\000\031\000\
\031\000\031\000\000\000\000\000\000\000\000\000\000\000\031\000\
\031\000\031\000\000\000\000\000\022\000\000\000\022\000\022\000\
\031\000\000\000\022\000\000\000\000\000\000\000\022\000\022\000\
\022\000\022\000\022\000\022\000\022\000\000\000\022\000\000\000\
\000\000\022\000\022\000\022\000\022\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\022\000\022\000\022\000\022\000\
\022\000\022\000\022\000\000\000\022\000\021\000\022\000\022\000\
\022\000\000\000\000\000\000\000\000\000\000\000\022\000\022\000\
\022\000\000\000\023\000\000\000\023\000\023\000\000\000\022\000\
\023\000\000\000\000\000\000\000\023\000\023\000\023\000\023\000\
\023\000\023\000\023\000\000\000\023\000\000\000\000\000\023\000\
\023\000\023\000\023\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\023\000\023\000\023\000\023\000\023\000\023\000\
\023\000\000\000\023\000\020\000\023\000\023\000\023\000\000\000\
\000\000\000\000\000\000\000\000\023\000\023\000\023\000\000\000\
\024\000\000\000\024\000\024\000\000\000\023\000\024\000\000\000\
\000\000\000\000\024\000\024\000\024\000\024\000\024\000\024\000\
\024\000\000\000\024\000\000\000\000\000\024\000\024\000\024\000\
\024\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\024\000\024\000\024\000\024\000\024\000\024\000\024\000\000\000\
\024\000\008\000\024\000\024\000\024\000\000\000\000\000\000\000\
\000\000\000\000\024\000\024\000\024\000\000\000\044\000\000\000\
\044\000\044\000\000\000\024\000\044\000\000\000\000\000\000\000\
\044\000\044\000\044\000\044\000\044\000\044\000\044\000\000\000\
\044\000\000\000\000\000\044\000\044\000\044\000\044\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\044\000\044\000\
\044\000\044\000\044\000\044\000\044\000\000\000\044\000\005\000\
\044\000\044\000\044\000\000\000\000\000\000\000\000\000\000\000\
\044\000\044\000\044\000\000\000\043\000\000\000\043\000\043\000\
\000\000\044\000\043\000\000\000\000\000\000\000\043\000\043\000\
\043\000\043\000\043\000\043\000\043\000\000\000\043\000\000\000\
\000\000\043\000\043\000\043\000\043\000\000\000\045\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\043\000\043\000\043\000\043\000\
\043\000\043\000\043\000\000\000\043\000\004\000\043\000\043\000\
\043\000\000\000\000\000\000\000\000\000\000\000\043\000\043\000\
\043\000\000\000\000\000\021\000\000\000\021\000\021\000\043\000\
\000\000\021\000\000\000\000\000\000\000\021\000\021\000\021\000\
\021\000\021\000\021\000\021\000\000\000\021\000\000\000\000\000\
\021\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\021\000\021\000\021\000\021\000\000\000\
\000\000\000\000\000\000\021\000\033\000\021\000\021\000\021\000\
\000\000\000\000\000\000\000\000\000\000\021\000\021\000\021\000\
\000\000\020\000\000\000\020\000\020\000\000\000\021\000\020\000\
\000\000\000\000\000\000\020\000\020\000\020\000\020\000\020\000\
\020\000\020\000\000\000\020\000\000\000\000\000\020\000\020\000\
\020\000\020\000\000\000\002\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\020\000\020\000\020\000\020\000\000\000\000\000\000\000\
\000\000\020\000\009\000\020\000\020\000\020\000\000\000\000\000\
\000\000\000\000\000\000\020\000\020\000\020\000\000\000\008\000\
\000\000\008\000\008\000\000\000\020\000\008\000\000\000\000\000\
\000\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
\000\000\008\000\000\000\000\000\008\000\008\000\008\000\008\000\
\000\000\001\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\008\000\
\008\000\000\000\000\000\000\000\000\000\000\000\000\000\008\000\
\003\000\008\000\008\000\008\000\000\000\000\000\000\000\000\000\
\000\000\008\000\008\000\008\000\000\000\005\000\000\000\005\000\
\005\000\000\000\008\000\005\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\005\000\000\000\005\000\
\000\000\000\000\005\000\005\000\005\000\005\000\000\000\010\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\045\000\005\000\045\000\045\000\
\000\000\000\000\045\000\000\000\000\000\005\000\011\000\005\000\
\005\000\005\000\000\000\000\000\045\000\000\000\045\000\005\000\
\005\000\005\000\000\000\004\000\000\000\004\000\004\000\000\000\
\005\000\004\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\004\000\045\000\004\000\000\000\000\000\
\004\000\004\000\004\000\004\000\045\000\000\000\045\000\045\000\
\045\000\000\000\000\000\000\000\000\000\000\000\045\000\045\000\
\045\000\041\000\000\000\004\000\000\000\000\000\000\000\045\000\
\000\000\000\000\000\000\004\000\000\000\004\000\004\000\004\000\
\000\000\000\000\000\000\000\000\000\000\004\000\004\000\004\000\
\000\000\000\000\033\000\000\000\033\000\033\000\004\000\000\000\
\033\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\033\000\000\000\033\000\000\000\000\000\033\000\
\033\000\033\000\033\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\002\000\033\000\002\000\002\000\000\000\000\000\002\000\
\000\000\000\000\033\000\000\000\033\000\033\000\033\000\000\000\
\000\000\002\000\000\000\002\000\033\000\033\000\033\000\000\000\
\009\000\000\000\009\000\009\000\000\000\033\000\009\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\009\000\002\000\009\000\000\000\000\000\009\000\009\000\009\000\
\009\000\002\000\000\000\002\000\002\000\002\000\000\000\000\000\
\000\000\000\000\000\000\002\000\002\000\002\000\000\000\001\000\
\009\000\001\000\001\000\000\000\002\000\001\000\000\000\000\000\
\009\000\000\000\009\000\009\000\009\000\000\000\000\000\001\000\
\000\000\001\000\009\000\009\000\009\000\000\000\003\000\000\000\
\003\000\003\000\000\000\009\000\003\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\003\000\001\000\
\003\000\000\000\000\000\003\000\003\000\000\000\003\000\001\000\
\000\000\001\000\001\000\001\000\000\000\000\000\000\000\000\000\
\000\000\001\000\001\000\001\000\000\000\010\000\003\000\010\000\
\010\000\000\000\001\000\010\000\000\000\000\000\003\000\000\000\
\003\000\003\000\003\000\000\000\000\000\010\000\000\000\010\000\
\003\000\003\000\003\000\000\000\011\000\000\000\011\000\011\000\
\000\000\003\000\011\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\011\000\010\000\011\000\000\000\
\000\000\000\000\000\000\000\000\000\000\010\000\000\000\010\000\
\010\000\010\000\000\000\000\000\000\000\000\000\000\000\010\000\
\010\000\010\000\000\000\000\000\011\000\000\000\000\000\000\000\
\010\000\000\000\000\000\000\000\011\000\000\000\011\000\011\000\
\011\000\000\000\000\000\000\000\041\000\000\000\011\000\011\000\
\011\000\041\000\041\000\041\000\041\000\041\000\041\000\011\000\
\041\000\000\000\000\000\000\000\041\000\041\000\041\000\041\000\
\000\000\000\000\000\000\050\000\000\000\053\000\054\000\000\000\
\000\000\000\000\000\000\000\000\079\000\000\000\000\000\000\000\
\041\000\041\000\041\000\041\000\041\000\041\000\041\000\000\000\
\000\000\041\000\092\000\094\000\095\000\000\000\000\000\100\000\
\000\000\052\000\000\000\041\000\025\000\026\000\000\000\027\000\
\000\000\000\000\000\000\000\000\000\000\028\000\112\000\113\000\
\114\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\029\000\030\000\000\000\000\000\000\000\000\000\031\000\
\032\000\033\000\034\000\035\000\036\000\037\000\038\000\039\000\
\040\000\041\000\042\000\043\000\044\000\045\000\000\000\000\000\
\046\000\047\000\048\000\000\000\000\000\000\000\163\000\000\000\
\000\000\164\000\167\000\168\000\000\000\000\000\049\000\000\000\
\000\000\000\000\000\000\055\000\000\000\176\000\177\000\178\000\
\179\000\180\000\181\000\182\000\183\000\184\000\185\000\186\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\189\000\190\000\191\000\192\000\193\000\
\194\000\195\000\196\000\197\000\198\000\199\000\201\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\052\000\000\000\209\000\
\025\000\026\000\000\000\027\000\000\000\213\000\000\000\000\000\
\214\000\028\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\220\000\221\000\222\000\223\000\029\000\030\000\226\000\
\000\000\000\000\000\000\031\000\032\000\033\000\034\000\035\000\
\036\000\037\000\038\000\039\000\040\000\041\000\042\000\043\000\
\044\000\045\000\000\000\000\000\046\000\047\000\048\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\049\000\245\000\248\000\000\000\000\000\000\000\
\000\000\000\000\164\000\000\000\244\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\255\000\000\001\000\000\001\001\002\001\000\000\003\001\000\000\
\004\001\000\000\000\000\000\000\245\000\000\000\000\000\000\000\
\000\000\000\000\052\000\000\000\012\001\025\000\026\000\000\000\
\027\000\000\000\000\000\000\000\000\000\000\000\028\000\000\000\
\022\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\025\001\029\000\030\000\027\001\000\000\000\000\245\000\
\031\000\032\000\033\000\034\000\035\000\036\000\037\000\038\000\
\039\000\040\000\041\000\042\000\043\000\044\000\045\000\000\000\
\115\000\046\000\047\000\048\000\000\000\116\000\117\000\118\000\
\119\000\120\000\121\000\000\000\122\000\000\000\000\000\049\000\
\123\000\124\000\125\000\126\000\158\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\127\000\128\000\129\000\130\000\
\131\000\132\000\133\000\000\000\000\000\000\000\000\000\115\000\
\000\000\000\000\000\000\000\000\116\000\117\000\118\000\119\000\
\120\000\121\000\000\000\122\000\000\000\000\000\028\001\123\000\
\124\000\125\000\126\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\127\000\128\000\129\000\130\000\131\000\
\132\000\133\000\052\000\000\000\000\000\025\000\026\000\000\000\
\027\000\000\000\000\000\000\000\000\000\000\000\028\000\000\000\
\000\000\000\000\000\000\000\000\000\000\032\001\000\000\000\000\
\000\000\000\000\029\000\030\000\000\000\000\000\000\000\000\000\
\031\000\032\000\033\000\034\000\035\000\036\000\037\000\038\000\
\039\000\040\000\041\000\042\000\043\000\044\000\045\000\000\000\
\000\000\046\000\047\000\048\000\000\000\024\000\000\000\247\000\
\025\000\026\000\000\000\027\000\000\000\000\000\000\000\049\000\
\000\000\028\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\029\000\030\000\000\000\
\000\000\000\000\000\000\031\000\032\000\033\000\034\000\035\000\
\036\000\037\000\038\000\039\000\040\000\041\000\042\000\043\000\
\044\000\045\000\000\000\000\000\046\000\047\000\048\000\052\000\
\000\000\000\000\025\000\026\000\000\000\027\000\000\000\000\000\
\000\000\000\000\049\000\028\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\029\000\
\030\000\000\000\000\000\000\000\000\000\031\000\032\000\033\000\
\034\000\035\000\036\000\037\000\038\000\039\000\040\000\041\000\
\042\000\043\000\044\000\045\000\000\000\000\000\046\000\047\000\
\048\000\052\000\000\000\000\000\025\000\026\000\000\000\027\000\
\000\000\000\000\000\000\000\000\049\000\028\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\029\000\030\000\000\000\000\000\000\000\000\000\031\000\
\032\000\033\000\034\000\035\000\036\000\037\000\038\000\039\000\
\040\000\041\000\042\000\043\000\044\000\045\000\000\000\115\000\
\000\000\000\000\000\000\000\000\116\000\117\000\118\000\119\000\
\120\000\121\000\000\000\122\000\000\000\000\000\049\000\123\000\
\124\000\125\000\126\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\127\000\128\000\129\000\130\000\131\000\
\132\000\133\000\227\000\000\000\000\000\000\000\217\000\115\000\
\000\000\000\000\000\000\000\000\116\000\117\000\118\000\119\000\
\120\000\121\000\000\000\122\000\000\000\000\000\000\000\123\000\
\124\000\125\000\126\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\127\000\128\000\129\000\130\000\131\000\
\132\000\133\000\229\000\000\000\000\000\000\000\000\000\115\000\
\000\000\000\000\000\000\000\000\116\000\117\000\118\000\119\000\
\120\000\121\000\000\000\122\000\000\000\000\000\000\000\123\000\
\124\000\125\000\126\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\127\000\128\000\129\000\130\000\131\000\
\132\000\133\000\230\000\000\000\000\000\000\000\000\000\115\000\
\000\000\000\000\000\000\000\000\116\000\117\000\118\000\119\000\
\120\000\121\000\000\000\122\000\000\000\000\000\000\000\123\000\
\124\000\125\000\126\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\127\000\128\000\129\000\130\000\131\000\
\132\000\133\000\231\000\000\000\000\000\000\000\000\000\115\000\
\000\000\000\000\000\000\000\000\116\000\117\000\118\000\119\000\
\120\000\121\000\000\000\122\000\000\000\000\000\000\000\123\000\
\124\000\125\000\126\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\127\000\128\000\129\000\130\000\131\000\
\132\000\133\000\234\000\000\000\000\000\000\000\000\000\115\000\
\000\000\000\000\000\000\000\000\116\000\117\000\118\000\119\000\
\120\000\121\000\000\000\122\000\000\000\000\000\000\000\123\000\
\124\000\125\000\126\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\127\000\128\000\129\000\130\000\131\000\
\132\000\133\000\237\000\000\000\000\000\000\000\000\000\115\000\
\000\000\000\000\000\000\000\000\116\000\117\000\118\000\119\000\
\120\000\121\000\000\000\122\000\000\000\000\000\000\000\123\000\
\124\000\125\000\126\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\127\000\128\000\129\000\130\000\131\000\
\132\000\133\000\014\001\000\000\000\000\000\000\000\000\115\000\
\000\000\000\000\000\000\000\000\116\000\117\000\118\000\119\000\
\120\000\121\000\000\000\122\000\000\000\000\000\000\000\123\000\
\124\000\125\000\126\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\127\000\128\000\129\000\130\000\131\000\
\132\000\133\000\015\001\000\000\000\000\000\000\000\000\115\000\
\000\000\000\000\000\000\000\000\116\000\117\000\118\000\119\000\
\120\000\121\000\000\000\122\000\000\000\000\000\000\000\123\000\
\124\000\125\000\126\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\127\000\128\000\129\000\130\000\131\000\
\132\000\133\000\016\001\000\000\000\000\000\000\000\000\115\000\
\000\000\000\000\000\000\000\000\116\000\117\000\118\000\119\000\
\120\000\121\000\000\000\122\000\000\000\000\000\000\000\123\000\
\124\000\125\000\126\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\127\000\128\000\129\000\130\000\131\000\
\132\000\133\000\031\001\000\000\000\000\000\000\000\000\115\000\
\000\000\000\000\000\000\000\000\116\000\117\000\118\000\119\000\
\120\000\121\000\000\000\122\000\000\000\000\000\000\000\123\000\
\124\000\125\000\126\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\127\000\128\000\129\000\130\000\131\000\
\132\000\133\000\252\000\000\000\000\000\115\000\000\000\000\000\
\000\000\000\000\116\000\117\000\118\000\119\000\120\000\121\000\
\000\000\122\000\238\000\000\000\115\000\123\000\124\000\125\000\
\126\000\116\000\117\000\118\000\119\000\120\000\121\000\000\000\
\122\000\000\000\000\000\000\000\123\000\124\000\125\000\126\000\
\000\000\127\000\128\000\129\000\130\000\131\000\132\000\133\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\127\000\128\000\129\000\130\000\131\000\132\000\133\000\115\000\
\000\000\000\000\000\000\000\000\116\000\117\000\118\000\119\000\
\120\000\121\000\000\000\122\000\000\000\000\000\115\000\123\000\
\124\000\125\000\126\000\116\000\117\000\118\000\119\000\120\000\
\121\000\000\000\122\000\000\000\000\000\000\000\123\000\124\000\
\125\000\126\000\000\000\127\000\128\000\129\000\130\000\131\000\
\132\000\133\000\239\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\127\000\128\000\129\000\130\000\131\000\132\000\
\133\000\011\001\115\000\000\000\000\000\000\000\000\000\116\000\
\117\000\118\000\119\000\120\000\121\000\000\000\122\000\000\000\
\000\000\115\000\123\000\124\000\125\000\126\000\116\000\117\000\
\118\000\119\000\120\000\121\000\218\000\122\000\000\000\000\000\
\000\000\123\000\124\000\125\000\126\000\171\000\127\000\128\000\
\129\000\130\000\131\000\132\000\133\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\127\000\128\000\129\000\
\130\000\131\000\132\000\133\000\115\000\000\000\000\000\000\000\
\000\000\116\000\117\000\118\000\119\000\120\000\121\000\228\000\
\122\000\000\000\000\000\115\000\123\000\124\000\125\000\126\000\
\116\000\117\000\118\000\119\000\120\000\121\000\232\000\122\000\
\000\000\000\000\000\000\123\000\124\000\125\000\126\000\000\000\
\127\000\128\000\129\000\130\000\131\000\132\000\133\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\127\000\
\128\000\129\000\130\000\131\000\132\000\133\000\115\000\000\000\
\000\000\000\000\000\000\116\000\117\000\118\000\119\000\120\000\
\121\000\233\000\122\000\000\000\000\000\115\000\123\000\124\000\
\125\000\126\000\116\000\117\000\118\000\119\000\120\000\121\000\
\235\000\122\000\000\000\000\000\000\000\123\000\124\000\125\000\
\126\000\000\000\127\000\128\000\129\000\130\000\131\000\132\000\
\133\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\127\000\128\000\129\000\130\000\131\000\132\000\133\000\
\115\000\000\000\000\000\000\000\000\000\116\000\117\000\118\000\
\119\000\120\000\121\000\236\000\122\000\000\000\000\000\115\000\
\123\000\124\000\125\000\126\000\116\000\117\000\118\000\119\000\
\120\000\121\000\017\001\122\000\000\000\000\000\000\000\123\000\
\124\000\125\000\126\000\000\000\127\000\128\000\129\000\130\000\
\131\000\132\000\133\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\127\000\128\000\129\000\130\000\131\000\
\132\000\133\000\115\000\000\000\000\000\000\000\000\000\116\000\
\117\000\118\000\119\000\120\000\121\000\000\000\122\000\000\000\
\000\000\115\000\123\000\124\000\125\000\126\000\116\000\117\000\
\118\000\119\000\120\000\121\000\000\000\122\000\000\000\000\000\
\000\000\000\000\000\000\125\000\000\000\000\000\127\000\128\000\
\129\000\130\000\131\000\132\000\133\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\127\000\128\000\129\000\
\130\000\131\000\132\000\133\000\003\000\000\000\000\000\000\000\
\004\000\005\000\000\000\000\000\006\000\000\000\000\000\007\000\
\000\000\000\000\008\000\009\000\010\000\000\000\000\000\011\000\
\012\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\013\000"

let yycheck = "\082\000\
\000\000\244\000\000\000\000\000\000\000\000\000\084\000\000\000\
\014\001\000\000\000\000\000\000\029\000\030\000\014\001\015\001\
\001\001\006\001\006\001\022\001\001\001\006\001\005\001\005\001\
\001\000\006\001\009\001\010\001\010\001\081\001\082\001\001\001\
\000\000\003\001\022\001\001\001\023\001\000\000\001\001\006\001\
\001\001\001\001\000\000\000\000\014\001\015\001\066\001\068\001\
\065\001\068\001\014\001\072\001\135\000\072\001\001\001\056\001\
\003\001\004\001\005\001\000\000\007\001\005\001\005\001\000\000\
\005\001\050\001\013\001\014\001\015\001\050\001\073\001\077\001\
\061\001\061\001\080\001\081\001\005\001\077\001\025\001\026\001\
\005\001\005\001\082\001\050\001\031\001\032\001\033\001\034\001\
\035\001\036\001\037\001\038\001\039\001\040\001\041\001\042\001\
\043\001\044\001\045\001\001\001\000\000\048\001\049\001\050\001\
\006\001\005\001\076\001\077\001\078\001\079\001\080\001\081\001\
\082\001\077\001\011\001\062\001\080\001\081\001\005\001\016\001\
\017\001\018\001\019\001\020\001\021\001\000\000\023\001\011\001\
\005\001\076\001\077\001\078\001\079\001\080\001\081\001\082\001\
\005\001\215\000\005\001\023\001\022\001\050\001\050\001\001\001\
\005\001\009\001\001\001\064\001\050\001\024\001\047\001\048\001\
\049\001\050\001\051\001\052\001\053\001\174\000\061\001\001\001\
\022\001\001\001\061\001\001\001\001\001\050\001\081\001\004\001\
\005\001\053\001\007\001\081\001\005\001\022\001\024\001\053\001\
\013\001\057\001\006\001\053\001\007\001\012\001\006\001\001\001\
\054\001\001\001\006\001\000\000\025\001\026\001\000\000\006\001\
\019\001\001\001\031\001\032\001\033\001\034\001\035\001\036\001\
\037\001\038\001\039\001\040\001\041\001\042\001\043\001\044\001\
\045\001\006\001\054\001\048\001\049\001\050\001\011\001\001\001\
\000\000\024\001\006\001\016\001\017\001\018\001\019\001\020\001\
\021\001\062\001\023\001\012\001\001\001\006\001\027\001\028\001\
\029\001\030\001\000\000\072\001\073\001\000\000\000\000\006\001\
\000\000\012\001\000\000\000\000\054\001\000\000\000\000\026\000\
\054\001\000\000\047\001\048\001\049\001\050\001\051\001\052\001\
\053\001\011\001\240\000\008\000\206\000\210\000\006\001\218\000\
\008\001\009\001\018\000\011\001\012\001\023\001\018\000\255\255\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\022\001\255\255\027\001\028\001\029\001\030\001\022\001\
\022\001\024\001\255\255\255\255\255\255\255\255\048\001\049\001\
\050\001\051\001\052\001\053\001\255\255\255\255\046\001\047\001\
\048\001\049\001\050\001\051\001\052\001\053\001\054\001\000\000\
\056\001\057\001\058\001\057\001\056\001\255\255\057\001\056\001\
\064\001\065\001\066\001\056\001\255\255\006\001\066\001\008\001\
\009\001\073\001\011\001\012\001\073\001\255\255\255\255\016\001\
\017\001\018\001\019\001\020\001\021\001\022\001\023\001\024\001\
\056\001\057\001\027\001\028\001\029\001\030\001\057\001\255\255\
\064\001\065\001\056\001\057\001\057\001\064\001\065\001\255\255\
\255\255\255\255\064\001\064\001\255\255\046\001\047\001\048\001\
\049\001\050\001\051\001\052\001\053\001\054\001\000\000\056\001\
\057\001\058\001\022\001\255\255\255\255\255\255\011\001\064\001\
\065\001\066\001\255\255\006\001\255\255\008\001\009\001\255\255\
\073\001\012\001\023\001\255\255\255\255\016\001\017\001\018\001\
\019\001\020\001\021\001\022\001\255\255\024\001\255\255\255\255\
\027\001\028\001\029\001\030\001\056\001\057\001\255\255\255\255\
\255\255\255\255\255\255\255\255\064\001\050\001\051\001\052\001\
\053\001\255\255\255\255\046\001\047\001\048\001\049\001\050\001\
\051\001\052\001\255\255\054\001\000\000\056\001\057\001\058\001\
\255\255\255\255\255\255\255\255\255\255\064\001\065\001\066\001\
\255\255\006\001\255\255\008\001\009\001\255\255\073\001\012\001\
\255\255\255\255\255\255\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\255\255\024\001\255\255\255\255\027\001\028\001\
\029\001\030\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\046\001\047\001\048\001\049\001\050\001\051\001\052\001\
\255\255\054\001\000\000\056\001\057\001\058\001\255\255\255\255\
\255\255\255\255\255\255\064\001\065\001\066\001\255\255\006\001\
\255\255\008\001\009\001\255\255\073\001\012\001\255\255\255\255\
\255\255\016\001\017\001\018\001\019\001\020\001\021\001\022\001\
\255\255\024\001\255\255\255\255\027\001\028\001\029\001\030\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\046\001\
\047\001\048\001\049\001\050\001\051\001\052\001\255\255\054\001\
\000\000\056\001\057\001\058\001\255\255\255\255\255\255\255\255\
\255\255\064\001\065\001\066\001\255\255\006\001\255\255\008\001\
\009\001\255\255\073\001\012\001\255\255\255\255\255\255\016\001\
\017\001\018\001\019\001\020\001\021\001\022\001\255\255\024\001\
\255\255\255\255\027\001\028\001\029\001\030\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\046\001\047\001\048\001\
\049\001\050\001\051\001\052\001\255\255\054\001\000\000\056\001\
\057\001\058\001\255\255\255\255\255\255\255\255\255\255\064\001\
\065\001\066\001\255\255\255\255\006\001\255\255\008\001\009\001\
\073\001\255\255\012\001\255\255\255\255\255\255\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\255\255\024\001\255\255\
\255\255\027\001\028\001\029\001\030\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\046\001\047\001\048\001\049\001\
\050\001\051\001\052\001\255\255\054\001\000\000\056\001\057\001\
\058\001\255\255\255\255\255\255\255\255\255\255\064\001\065\001\
\066\001\255\255\006\001\255\255\008\001\009\001\255\255\073\001\
\012\001\255\255\255\255\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\255\255\024\001\255\255\255\255\027\001\
\028\001\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\046\001\047\001\048\001\049\001\050\001\051\001\
\052\001\255\255\054\001\000\000\056\001\057\001\058\001\255\255\
\255\255\255\255\255\255\255\255\064\001\065\001\066\001\255\255\
\006\001\255\255\008\001\009\001\255\255\073\001\012\001\255\255\
\255\255\255\255\016\001\017\001\018\001\019\001\020\001\021\001\
\022\001\255\255\024\001\255\255\255\255\027\001\028\001\029\001\
\030\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\046\001\047\001\048\001\049\001\050\001\051\001\052\001\255\255\
\054\001\000\000\056\001\057\001\058\001\255\255\255\255\255\255\
\255\255\255\255\064\001\065\001\066\001\255\255\006\001\255\255\
\008\001\009\001\255\255\073\001\012\001\255\255\255\255\255\255\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\255\255\
\024\001\255\255\255\255\027\001\028\001\029\001\030\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\046\001\047\001\
\048\001\049\001\050\001\051\001\052\001\255\255\054\001\000\000\
\056\001\057\001\058\001\255\255\255\255\255\255\255\255\255\255\
\064\001\065\001\066\001\255\255\006\001\255\255\008\001\009\001\
\255\255\073\001\012\001\255\255\255\255\255\255\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\255\255\024\001\255\255\
\255\255\027\001\028\001\029\001\030\001\255\255\000\000\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\046\001\047\001\048\001\049\001\
\050\001\051\001\052\001\255\255\054\001\000\000\056\001\057\001\
\058\001\255\255\255\255\255\255\255\255\255\255\064\001\065\001\
\066\001\255\255\255\255\006\001\255\255\008\001\009\001\073\001\
\255\255\012\001\255\255\255\255\255\255\016\001\017\001\018\001\
\019\001\020\001\021\001\022\001\255\255\024\001\255\255\255\255\
\027\001\028\001\029\001\030\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\046\001\047\001\048\001\049\001\255\255\
\255\255\255\255\255\255\054\001\000\000\056\001\057\001\058\001\
\255\255\255\255\255\255\255\255\255\255\064\001\065\001\066\001\
\255\255\006\001\255\255\008\001\009\001\255\255\073\001\012\001\
\255\255\255\255\255\255\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\255\255\024\001\255\255\255\255\027\001\028\001\
\029\001\030\001\255\255\000\000\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\046\001\047\001\048\001\049\001\255\255\255\255\255\255\
\255\255\054\001\000\000\056\001\057\001\058\001\255\255\255\255\
\255\255\255\255\255\255\064\001\065\001\066\001\255\255\006\001\
\255\255\008\001\009\001\255\255\073\001\012\001\255\255\255\255\
\255\255\016\001\017\001\018\001\019\001\020\001\021\001\022\001\
\255\255\024\001\255\255\255\255\027\001\028\001\029\001\030\001\
\255\255\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\046\001\
\047\001\255\255\255\255\255\255\255\255\255\255\255\255\054\001\
\000\000\056\001\057\001\058\001\255\255\255\255\255\255\255\255\
\255\255\064\001\065\001\066\001\255\255\006\001\255\255\008\001\
\009\001\255\255\073\001\012\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\022\001\255\255\024\001\
\255\255\255\255\027\001\028\001\029\001\030\001\255\255\000\000\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\006\001\046\001\008\001\009\001\
\255\255\255\255\012\001\255\255\255\255\054\001\000\000\056\001\
\057\001\058\001\255\255\255\255\022\001\255\255\024\001\064\001\
\065\001\066\001\255\255\006\001\255\255\008\001\009\001\255\255\
\073\001\012\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\022\001\046\001\024\001\255\255\255\255\
\027\001\028\001\029\001\030\001\054\001\255\255\056\001\057\001\
\058\001\255\255\255\255\255\255\255\255\255\255\064\001\065\001\
\066\001\000\000\255\255\046\001\255\255\255\255\255\255\073\001\
\255\255\255\255\255\255\054\001\255\255\056\001\057\001\058\001\
\255\255\255\255\255\255\255\255\255\255\064\001\065\001\066\001\
\255\255\255\255\006\001\255\255\008\001\009\001\073\001\255\255\
\012\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\022\001\255\255\024\001\255\255\255\255\027\001\
\028\001\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\006\001\046\001\008\001\009\001\255\255\255\255\012\001\
\255\255\255\255\054\001\255\255\056\001\057\001\058\001\255\255\
\255\255\022\001\255\255\024\001\064\001\065\001\066\001\255\255\
\006\001\255\255\008\001\009\001\255\255\073\001\012\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\022\001\046\001\024\001\255\255\255\255\027\001\028\001\029\001\
\030\001\054\001\255\255\056\001\057\001\058\001\255\255\255\255\
\255\255\255\255\255\255\064\001\065\001\066\001\255\255\006\001\
\046\001\008\001\009\001\255\255\073\001\012\001\255\255\255\255\
\054\001\255\255\056\001\057\001\058\001\255\255\255\255\022\001\
\255\255\024\001\064\001\065\001\066\001\255\255\006\001\255\255\
\008\001\009\001\255\255\073\001\012\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\022\001\046\001\
\024\001\255\255\255\255\027\001\028\001\255\255\030\001\054\001\
\255\255\056\001\057\001\058\001\255\255\255\255\255\255\255\255\
\255\255\064\001\065\001\066\001\255\255\006\001\046\001\008\001\
\009\001\255\255\073\001\012\001\255\255\255\255\054\001\255\255\
\056\001\057\001\058\001\255\255\255\255\022\001\255\255\024\001\
\064\001\065\001\066\001\255\255\006\001\255\255\008\001\009\001\
\255\255\073\001\012\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\022\001\046\001\024\001\255\255\
\255\255\255\255\255\255\255\255\255\255\054\001\255\255\056\001\
\057\001\058\001\255\255\255\255\255\255\255\255\255\255\064\001\
\065\001\066\001\255\255\255\255\046\001\255\255\255\255\255\255\
\073\001\255\255\255\255\255\255\054\001\255\255\056\001\057\001\
\058\001\255\255\255\255\255\255\011\001\255\255\064\001\065\001\
\066\001\016\001\017\001\018\001\019\001\020\001\021\001\073\001\
\023\001\255\255\255\255\255\255\027\001\028\001\029\001\030\001\
\255\255\255\255\255\255\003\000\255\255\005\000\006\000\255\255\
\255\255\255\255\255\255\255\255\012\000\255\255\255\255\255\255\
\047\001\048\001\049\001\050\001\051\001\052\001\053\001\255\255\
\255\255\056\001\026\000\027\000\028\000\255\255\255\255\031\000\
\255\255\001\001\255\255\066\001\004\001\005\001\255\255\007\001\
\255\255\255\255\255\255\255\255\255\255\013\001\046\000\047\000\
\048\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\025\001\026\001\255\255\255\255\255\255\255\255\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\038\001\039\001\
\040\001\041\001\042\001\043\001\044\001\045\001\255\255\255\255\
\048\001\049\001\050\001\255\255\255\255\255\255\086\000\255\255\
\255\255\089\000\090\000\091\000\255\255\255\255\062\001\255\255\
\255\255\255\255\255\255\067\001\255\255\101\000\102\000\103\000\
\104\000\105\000\106\000\107\000\108\000\109\000\110\000\111\000\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\123\000\124\000\125\000\126\000\127\000\
\128\000\129\000\130\000\131\000\132\000\133\000\134\000\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\001\001\255\255\151\000\
\004\001\005\001\255\255\007\001\255\255\157\000\255\255\255\255\
\160\000\013\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\169\000\170\000\171\000\172\000\025\001\026\001\175\000\
\255\255\255\255\255\255\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\039\001\040\001\041\001\042\001\043\001\
\044\001\045\001\255\255\255\255\048\001\049\001\050\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\062\001\211\000\212\000\255\255\255\255\255\255\
\255\255\255\255\218\000\255\255\072\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\232\000\233\000\255\255\235\000\236\000\255\255\238\000\255\255\
\240\000\255\255\255\255\255\255\244\000\255\255\255\255\255\255\
\255\255\255\255\001\001\255\255\252\000\004\001\005\001\255\255\
\007\001\255\255\255\255\255\255\255\255\255\255\013\001\255\255\
\008\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\017\001\025\001\026\001\020\001\255\255\255\255\023\001\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\038\001\
\039\001\040\001\041\001\042\001\043\001\044\001\045\001\255\255\
\011\001\048\001\049\001\050\001\255\255\016\001\017\001\018\001\
\019\001\020\001\021\001\255\255\023\001\255\255\255\255\062\001\
\027\001\028\001\029\001\030\001\067\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\047\001\048\001\049\001\050\001\
\051\001\052\001\053\001\255\255\255\255\255\255\255\255\011\001\
\255\255\255\255\255\255\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\255\255\023\001\255\255\255\255\073\001\027\001\
\028\001\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\047\001\048\001\049\001\050\001\051\001\
\052\001\053\001\001\001\255\255\255\255\004\001\005\001\255\255\
\007\001\255\255\255\255\255\255\255\255\255\255\013\001\255\255\
\255\255\255\255\255\255\255\255\255\255\073\001\255\255\255\255\
\255\255\255\255\025\001\026\001\255\255\255\255\255\255\255\255\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\038\001\
\039\001\040\001\041\001\042\001\043\001\044\001\045\001\255\255\
\255\255\048\001\049\001\050\001\255\255\001\001\255\255\054\001\
\004\001\005\001\255\255\007\001\255\255\255\255\255\255\062\001\
\255\255\013\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\025\001\026\001\255\255\
\255\255\255\255\255\255\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\039\001\040\001\041\001\042\001\043\001\
\044\001\045\001\255\255\255\255\048\001\049\001\050\001\001\001\
\255\255\255\255\004\001\005\001\255\255\007\001\255\255\255\255\
\255\255\255\255\062\001\013\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\025\001\
\026\001\255\255\255\255\255\255\255\255\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\038\001\039\001\040\001\041\001\
\042\001\043\001\044\001\045\001\255\255\255\255\048\001\049\001\
\050\001\001\001\255\255\255\255\004\001\005\001\255\255\007\001\
\255\255\255\255\255\255\255\255\062\001\013\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\025\001\026\001\255\255\255\255\255\255\255\255\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\038\001\039\001\
\040\001\041\001\042\001\043\001\044\001\045\001\255\255\011\001\
\255\255\255\255\255\255\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\255\255\023\001\255\255\255\255\062\001\027\001\
\028\001\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\047\001\048\001\049\001\050\001\051\001\
\052\001\053\001\006\001\255\255\255\255\255\255\058\001\011\001\
\255\255\255\255\255\255\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\255\255\023\001\255\255\255\255\255\255\027\001\
\028\001\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\047\001\048\001\049\001\050\001\051\001\
\052\001\053\001\006\001\255\255\255\255\255\255\255\255\011\001\
\255\255\255\255\255\255\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\255\255\023\001\255\255\255\255\255\255\027\001\
\028\001\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\047\001\048\001\049\001\050\001\051\001\
\052\001\053\001\006\001\255\255\255\255\255\255\255\255\011\001\
\255\255\255\255\255\255\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\255\255\023\001\255\255\255\255\255\255\027\001\
\028\001\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\047\001\048\001\049\001\050\001\051\001\
\052\001\053\001\006\001\255\255\255\255\255\255\255\255\011\001\
\255\255\255\255\255\255\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\255\255\023\001\255\255\255\255\255\255\027\001\
\028\001\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\047\001\048\001\049\001\050\001\051\001\
\052\001\053\001\006\001\255\255\255\255\255\255\255\255\011\001\
\255\255\255\255\255\255\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\255\255\023\001\255\255\255\255\255\255\027\001\
\028\001\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\047\001\048\001\049\001\050\001\051\001\
\052\001\053\001\006\001\255\255\255\255\255\255\255\255\011\001\
\255\255\255\255\255\255\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\255\255\023\001\255\255\255\255\255\255\027\001\
\028\001\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\047\001\048\001\049\001\050\001\051\001\
\052\001\053\001\006\001\255\255\255\255\255\255\255\255\011\001\
\255\255\255\255\255\255\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\255\255\023\001\255\255\255\255\255\255\027\001\
\028\001\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\047\001\048\001\049\001\050\001\051\001\
\052\001\053\001\006\001\255\255\255\255\255\255\255\255\011\001\
\255\255\255\255\255\255\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\255\255\023\001\255\255\255\255\255\255\027\001\
\028\001\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\047\001\048\001\049\001\050\001\051\001\
\052\001\053\001\006\001\255\255\255\255\255\255\255\255\011\001\
\255\255\255\255\255\255\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\255\255\023\001\255\255\255\255\255\255\027\001\
\028\001\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\047\001\048\001\049\001\050\001\051\001\
\052\001\053\001\006\001\255\255\255\255\255\255\255\255\011\001\
\255\255\255\255\255\255\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\255\255\023\001\255\255\255\255\255\255\027\001\
\028\001\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\047\001\048\001\049\001\050\001\051\001\
\052\001\053\001\008\001\255\255\255\255\011\001\255\255\255\255\
\255\255\255\255\016\001\017\001\018\001\019\001\020\001\021\001\
\255\255\023\001\009\001\255\255\011\001\027\001\028\001\029\001\
\030\001\016\001\017\001\018\001\019\001\020\001\021\001\255\255\
\023\001\255\255\255\255\255\255\027\001\028\001\029\001\030\001\
\255\255\047\001\048\001\049\001\050\001\051\001\052\001\053\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\047\001\048\001\049\001\050\001\051\001\052\001\053\001\011\001\
\255\255\255\255\255\255\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\255\255\023\001\255\255\255\255\011\001\027\001\
\028\001\029\001\030\001\016\001\017\001\018\001\019\001\020\001\
\021\001\255\255\023\001\255\255\255\255\255\255\027\001\028\001\
\029\001\030\001\255\255\047\001\048\001\049\001\050\001\051\001\
\052\001\053\001\054\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\047\001\048\001\049\001\050\001\051\001\052\001\
\053\001\054\001\011\001\255\255\255\255\255\255\255\255\016\001\
\017\001\018\001\019\001\020\001\021\001\255\255\023\001\255\255\
\255\255\011\001\027\001\028\001\029\001\030\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\255\255\255\255\
\255\255\027\001\028\001\029\001\030\001\046\001\047\001\048\001\
\049\001\050\001\051\001\052\001\053\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\047\001\048\001\049\001\
\050\001\051\001\052\001\053\001\011\001\255\255\255\255\255\255\
\255\255\016\001\017\001\018\001\019\001\020\001\021\001\022\001\
\023\001\255\255\255\255\011\001\027\001\028\001\029\001\030\001\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\255\255\255\255\255\255\027\001\028\001\029\001\030\001\255\255\
\047\001\048\001\049\001\050\001\051\001\052\001\053\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\047\001\
\048\001\049\001\050\001\051\001\052\001\053\001\011\001\255\255\
\255\255\255\255\255\255\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\023\001\255\255\255\255\011\001\027\001\028\001\
\029\001\030\001\016\001\017\001\018\001\019\001\020\001\021\001\
\022\001\023\001\255\255\255\255\255\255\027\001\028\001\029\001\
\030\001\255\255\047\001\048\001\049\001\050\001\051\001\052\001\
\053\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\047\001\048\001\049\001\050\001\051\001\052\001\053\001\
\011\001\255\255\255\255\255\255\255\255\016\001\017\001\018\001\
\019\001\020\001\021\001\022\001\023\001\255\255\255\255\011\001\
\027\001\028\001\029\001\030\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\255\255\255\255\255\255\027\001\
\028\001\029\001\030\001\255\255\047\001\048\001\049\001\050\001\
\051\001\052\001\053\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\047\001\048\001\049\001\050\001\051\001\
\052\001\053\001\011\001\255\255\255\255\255\255\255\255\016\001\
\017\001\018\001\019\001\020\001\021\001\255\255\023\001\255\255\
\255\255\011\001\027\001\028\001\029\001\030\001\016\001\017\001\
\018\001\019\001\020\001\021\001\255\255\023\001\255\255\255\255\
\255\255\255\255\255\255\029\001\255\255\255\255\047\001\048\001\
\049\001\050\001\051\001\052\001\053\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\047\001\048\001\049\001\
\050\001\051\001\052\001\053\001\055\001\255\255\255\255\255\255\
\059\001\060\001\255\255\255\255\063\001\255\255\255\255\066\001\
\255\255\255\255\069\001\070\001\071\001\255\255\255\255\074\001\
\075\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\086\001"

let yynames_const = "\
  LPAR\000\
  RPAR\000\
  IF\000\
  ELSE\000\
  COLON\000\
  COLONCOLON\000\
  DOT\000\
  DOTDOT\000\
  AMP\000\
  INT\000\
  FLOAT\000\
  LT\000\
  GT\000\
  LE\000\
  GE\000\
  EQ\000\
  NE\000\
  COMMA\000\
  ARROW\000\
  EQUAL\000\
  FORALL\000\
  EXISTS\000\
  IFF\000\
  IMPLIES\000\
  AND\000\
  OR\000\
  NOT\000\
  TRUE\000\
  FALSE\000\
  OLD\000\
  AT\000\
  RESULT\000\
  BLOCK_LENGTH\000\
  BASE_ADDR\000\
  OFFSET\000\
  SEPARATED\000\
  FULLSEPARATED\000\
  VALID\000\
  VALID_INDEX\000\
  VALID_RANGE\000\
  FRESH\000\
  THEN\000\
  QUESTION\000\
  MINUS\000\
  PLUS\000\
  STAR\000\
  SLASH\000\
  PERCENT\000\
  LSQUARE\000\
  RSQUARE\000\
  EOF\000\
  INVARIANT\000\
  VARIANT\000\
  DECREASES\000\
  FOR\000\
  LABEL\000\
  ASSERT\000\
  SEMICOLON\000\
  NULL\000\
  REQUIRES\000\
  ENSURES\000\
  ASSIGNS\000\
  LOOP_ASSIGNS\000\
  NOTHING\000\
  READS\000\
  LOGIC\000\
  PREDICATE\000\
  AXIOM\000\
  LBRACE\000\
  RBRACE\000\
  GHOST\000\
  SET\000\
  VOID\000\
  CHAR\000\
  SIGNED\000\
  UNSIGNED\000\
  SHORT\000\
  LONG\000\
  DOUBLE\000\
  STRUCT\000\
  ENUM\000\
  UNION\000\
  TYPE\000\
  "

let yynames_block = "\
  IDENTIFIER\000\
  STRING_LITERAL\000\
  TYPENAME\000\
  CONSTANT\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'lexpr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 90 "c/clparser.mly"
                      ( info (PLimplies (_1, _3)) )
# 1263 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'lexpr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 91 "c/clparser.mly"
                  ( info (PLiff (_1, _3)) )
# 1271 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'lexpr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 92 "c/clparser.mly"
                     ( info (PLor (_1, _3)) )
# 1279 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'lexpr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 93 "c/clparser.mly"
                     ( info (PLand (_1, _3)) )
# 1287 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 94 "c/clparser.mly"
                           ( info (PLnot _2) )
# 1294 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    Obj.repr(
# 95 "c/clparser.mly"
       ( info PLtrue )
# 1300 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    Obj.repr(
# 96 "c/clparser.mly"
        ( info PLfalse )
# 1306 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'lexpr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'relation) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 97 "c/clparser.mly"
                                           ( info (PLrel (_1, _2, _3)) )
# 1315 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'lexpr) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : 'lexpr) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 99 "c/clparser.mly"
      ( info (PLif (_2, _4, _6)) )
# 1324 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'ne_parameters) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 101 "c/clparser.mly"
      ( info (PLforall (_2, _4)) )
# 1332 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'ne_parameters) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 103 "c/clparser.mly"
      ( info (PLexists (_2, _4)) )
# 1340 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'lexpr) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'lexpr) in
    Obj.repr(
# 104 "c/clparser.mly"
                                        ( info (PLseparated (_3,_5)) )
# 1348 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'lexpr) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'lexpr) in
    Obj.repr(
# 105 "c/clparser.mly"
                                            ( info (PLfullseparated (_3,_5)) )
# 1356 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'lexpr) in
    Obj.repr(
# 106 "c/clparser.mly"
                        ( info (PLvalid (_3)) )
# 1363 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'lexpr) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'lexpr) in
    Obj.repr(
# 107 "c/clparser.mly"
                                          ( info (PLvalid_index (_3,_5)) )
# 1371 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 5 : 'lexpr) in
    let _5 = (Parsing.peek_val __caml_parser_env 3 : 'lexpr) in
    let _7 = (Parsing.peek_val __caml_parser_env 1 : 'lexpr) in
    Obj.repr(
# 109 "c/clparser.mly"
      ( info (PLvalid_range (_3,_5,_7)) )
# 1380 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'lexpr) in
    Obj.repr(
# 110 "c/clparser.mly"
                        ( info (PLfresh (_3)) )
# 1387 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    Obj.repr(
# 112 "c/clparser.mly"
       ( info PLnull )
# 1393 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Clogic.constant) in
    Obj.repr(
# 113 "c/clparser.mly"
           ( info (PLconstant _1) )
# 1400 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'lexpr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 114 "c/clparser.mly"
                   ( info (PLbinop (_1, Badd, _3)) )
# 1408 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'lexpr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 115 "c/clparser.mly"
                    ( info (PLbinop (_1, Bsub, _3)) )
# 1416 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'lexpr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 116 "c/clparser.mly"
                   ( info (PLbinop (_1, Bmul, _3)) )
# 1424 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'lexpr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 117 "c/clparser.mly"
                    ( info (PLbinop (_1, Bdiv, _3)) )
# 1432 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'lexpr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 118 "c/clparser.mly"
                      ( info (PLbinop (_1, Bmod, _3)) )
# 1440 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'lexpr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 119 "c/clparser.mly"
                         ( info (PLarrow (_1, _3)) )
# 1448 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'lexpr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 120 "c/clparser.mly"
                       ( info (PLdot (_1, _3)) )
# 1456 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'lexpr) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'lexpr) in
    Obj.repr(
# 121 "c/clparser.mly"
                              ( info (PLarrget (_1, _3)) )
# 1464 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : 'lexpr) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'lexpr_option) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'lexpr_option) in
    Obj.repr(
# 123 "c/clparser.mly"
   ( info (PLrange (_1, _3, _5)) )
# 1473 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 124 "c/clparser.mly"
                                ( info (PLunop (Uminus, _2)) )
# 1480 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 125 "c/clparser.mly"
                               ( _2 )
# 1487 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 126 "c/clparser.mly"
             ( info (PLunop (Ustar, _2)) )
# 1494 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 127 "c/clparser.mly"
            ( info (PLunop (Uamp, _2)) )
# 1501 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'lexpr) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'lexpr) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 129 "c/clparser.mly"
    ( info (PLif (_1, _3, _5)) )
# 1510 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'lexpr) in
    Obj.repr(
# 130 "c/clparser.mly"
                      ( info (PLold _3) )
# 1517 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'lexpr) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 131 "c/clparser.mly"
                                      ( info (PLat (_3, _5)) )
# 1525 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'lexpr) in
    Obj.repr(
# 132 "c/clparser.mly"
                            ( info (PLbase_addr _3) )
# 1532 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'lexpr) in
    Obj.repr(
# 133 "c/clparser.mly"
                         ( info (PLoffset _3) )
# 1539 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'lexpr) in
    Obj.repr(
# 134 "c/clparser.mly"
                               ( info (PLblock_length _3) )
# 1546 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    Obj.repr(
# 135 "c/clparser.mly"
         ( info PLresult )
# 1552 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'lexpr) in
    Obj.repr(
# 137 "c/clparser.mly"
                                 ( _2 )
# 1559 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 138 "c/clparser.mly"
             ( info (PLvar (Info.default_var_info _1)) )
# 1566 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'lexpr_list) in
    Obj.repr(
# 140 "c/clparser.mly"
    ( info (PLapp (Info.default_logic_info _1, _3)) )
# 1574 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'logic_type_not_id) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 142 "c/clparser.mly"
                                                    ( info (PLcast (_2, _4)) )
# 1582 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'lexpr) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 144 "c/clparser.mly"
    ( match _2.lexpr_node with
	| PLvar x -> info (PLcast (LTvar x.Info.var_name, _4))
	| _ -> raise Parse_error )
# 1592 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 147 "c/clparser.mly"
                                               ( info (PLnamed (_1, _3)) )
# 1600 "c/clparser.ml"
               : 'lexpr))
; (fun __caml_parser_env ->
    Obj.repr(
# 151 "c/clparser.mly"
                ( None )
# 1606 "c/clparser.ml"
               : 'lexpr_option))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 152 "c/clparser.mly"
                ( Some _1 )
# 1613 "c/clparser.ml"
               : 'lexpr_option))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 156 "c/clparser.mly"
             ( LTvar _1 )
# 1620 "c/clparser.ml"
               : 'logic_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'stars) in
    Obj.repr(
# 157 "c/clparser.mly"
                   ( _2 (LTvar _1) )
# 1628 "c/clparser.ml"
               : 'logic_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logic_type_not_id) in
    Obj.repr(
# 158 "c/clparser.mly"
                    ( _1 )
# 1635 "c/clparser.ml"
               : 'logic_type))
; (fun __caml_parser_env ->
    Obj.repr(
# 162 "c/clparser.mly"
                 ( LTvoid )
# 1641 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    Obj.repr(
# 163 "c/clparser.mly"
                 ( LTint )
# 1647 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    Obj.repr(
# 164 "c/clparser.mly"
                 ( LTint )
# 1653 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    Obj.repr(
# 165 "c/clparser.mly"
                 ( LTint )
# 1659 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    Obj.repr(
# 166 "c/clparser.mly"
                 ( LTint )
# 1665 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    Obj.repr(
# 167 "c/clparser.mly"
                 ( LTint )
# 1671 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    Obj.repr(
# 168 "c/clparser.mly"
                 ( LTint )
# 1677 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    Obj.repr(
# 169 "c/clparser.mly"
                 ( LTint )
# 1683 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    Obj.repr(
# 170 "c/clparser.mly"
                 ( LTint )
# 1689 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    Obj.repr(
# 171 "c/clparser.mly"
                 ( LTint )
# 1695 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    Obj.repr(
# 172 "c/clparser.mly"
                 ( LTint )
# 1701 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    Obj.repr(
# 173 "c/clparser.mly"
                 ( LTint )
# 1707 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    Obj.repr(
# 174 "c/clparser.mly"
                 ( LTint )
# 1713 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    Obj.repr(
# 175 "c/clparser.mly"
                   ( LTint )
# 1719 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    Obj.repr(
# 177 "c/clparser.mly"
              ( LTint )
# 1725 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    Obj.repr(
# 179 "c/clparser.mly"
                     ( LTint )
# 1731 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    Obj.repr(
# 181 "c/clparser.mly"
              ( LTfloat )
# 1737 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    Obj.repr(
# 182 "c/clparser.mly"
              ( LTfloat )
# 1743 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    Obj.repr(
# 183 "c/clparser.mly"
              ( LTfloat )
# 1749 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 189 "c/clparser.mly"
                   ( LTvar _1 )
# 1756 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'logic_type_not_id) in
    Obj.repr(
# 190 "c/clparser.mly"
                         ( LTpointer _1 )
# 1763 "c/clparser.ml"
               : 'logic_type_not_id))
; (fun __caml_parser_env ->
    Obj.repr(
# 194 "c/clparser.mly"
       ( fun t -> LTpointer t )
# 1769 "c/clparser.ml"
               : 'stars))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'stars) in
    Obj.repr(
# 195 "c/clparser.mly"
             ( fun t -> _1 (LTpointer t) )
# 1776 "c/clparser.ml"
               : 'stars))
; (fun __caml_parser_env ->
    Obj.repr(
# 199 "c/clparser.mly"
          ( Lt )
# 1782 "c/clparser.ml"
               : 'relation))
; (fun __caml_parser_env ->
    Obj.repr(
# 200 "c/clparser.mly"
          ( Gt )
# 1788 "c/clparser.ml"
               : 'relation))
; (fun __caml_parser_env ->
    Obj.repr(
# 201 "c/clparser.mly"
          ( Le )
# 1794 "c/clparser.ml"
               : 'relation))
; (fun __caml_parser_env ->
    Obj.repr(
# 202 "c/clparser.mly"
          ( Ge )
# 1800 "c/clparser.ml"
               : 'relation))
; (fun __caml_parser_env ->
    Obj.repr(
# 203 "c/clparser.mly"
          ( Eq )
# 1806 "c/clparser.ml"
               : 'relation))
; (fun __caml_parser_env ->
    Obj.repr(
# 204 "c/clparser.mly"
          ( Neq )
# 1812 "c/clparser.ml"
               : 'relation))
; (fun __caml_parser_env ->
    Obj.repr(
# 208 "c/clparser.mly"
                ( [] )
# 1818 "c/clparser.ml"
               : 'lexpr_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'ne_lexpr_list) in
    Obj.repr(
# 209 "c/clparser.mly"
                 ( _1 )
# 1825 "c/clparser.ml"
               : 'lexpr_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 213 "c/clparser.mly"
                           ( [_1] )
# 1832 "c/clparser.ml"
               : 'ne_lexpr_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'lexpr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'ne_lexpr_list) in
    Obj.repr(
# 214 "c/clparser.mly"
                            ( _1 :: _3 )
# 1840 "c/clparser.ml"
               : 'ne_lexpr_list))
; (fun __caml_parser_env ->
    Obj.repr(
# 218 "c/clparser.mly"
                ( None )
# 1846 "c/clparser.ml"
               : 'pre_condition))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 219 "c/clparser.mly"
                 ( Some _2 )
# 1853 "c/clparser.ml"
               : 'pre_condition))
; (fun __caml_parser_env ->
    Obj.repr(
# 223 "c/clparser.mly"
                 ( None )
# 1859 "c/clparser.ml"
               : 'post_condition))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 224 "c/clparser.mly"
                ( Some _2 )
# 1866 "c/clparser.ml"
               : 'post_condition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'pre_condition) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'effects) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'post_condition) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'decreases) in
    Obj.repr(
# 229 "c/clparser.mly"
    ( { requires = _1; assigns = _2; ensures = _3; decreases = _4 } )
# 1876 "c/clparser.ml"
               : 'spec))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'invariant) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'loop_effects) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'variant) in
    Obj.repr(
# 234 "c/clparser.mly"
    ( { invariant = Some _1; loop_assigns = _2; variant = Some _3 } )
# 1885 "c/clparser.ml"
               : 'loop_annot))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'loop_effects) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'variant) in
    Obj.repr(
# 236 "c/clparser.mly"
    ( { invariant = None; loop_assigns = _1; variant = Some _2 } )
# 1893 "c/clparser.ml"
               : 'loop_annot))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'invariant) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'loop_effects) in
    Obj.repr(
# 238 "c/clparser.mly"
    ( { invariant = Some _1; loop_assigns = _2; variant = None } )
# 1901 "c/clparser.ml"
               : 'loop_annot))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'ne_loop_effects) in
    Obj.repr(
# 240 "c/clparser.mly"
    ( { invariant = None; loop_assigns = Some _1; variant = None } )
# 1908 "c/clparser.ml"
               : 'loop_annot))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 244 "c/clparser.mly"
                  ( _2 )
# 1915 "c/clparser.ml"
               : 'invariant))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'lexpr) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 248 "c/clparser.mly"
                               ( (_2, Some _4) )
# 1923 "c/clparser.ml"
               : 'variant))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 249 "c/clparser.mly"
                               ( (_2, None) )
# 1930 "c/clparser.ml"
               : 'variant))
; (fun __caml_parser_env ->
    Obj.repr(
# 253 "c/clparser.mly"
                  ( None )
# 1936 "c/clparser.ml"
               : 'decreases))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'variant) in
    Obj.repr(
# 254 "c/clparser.mly"
                    ( Some _2 )
# 1943 "c/clparser.ml"
               : 'decreases))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'annotation) in
    Obj.repr(
# 258 "c/clparser.mly"
                   ( _1 )
# 1950 "c/clparser.ml"
               : Cast.parsed_annot))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'decl) in
    Obj.repr(
# 262 "c/clparser.mly"
                   ( Adecl [_1] )
# 1957 "c/clparser.ml"
               : 'annotation))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'ghost_decl) in
    Obj.repr(
# 263 "c/clparser.mly"
                   ( Adecl _1 )
# 1964 "c/clparser.ml"
               : 'annotation))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'spec) in
    Obj.repr(
# 264 "c/clparser.mly"
                   ( Aspec _1 )
# 1971 "c/clparser.ml"
               : 'annotation))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'loop_annot) in
    Obj.repr(
# 265 "c/clparser.mly"
                   ( Aloop_annot _1 )
# 1978 "c/clparser.ml"
               : 'annotation))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 266 "c/clparser.mly"
                   ( Acode_annot (Assert _2) )
# 1985 "c/clparser.ml"
               : 'annotation))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 267 "c/clparser.mly"
                   ( Acode_annot (Label _2) )
# 1992 "c/clparser.ml"
               : 'annotation))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'ghost_lvalue) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 269 "c/clparser.mly"
                   ( Acode_annot(GhostSet(_2,_4)) )
# 2000 "c/clparser.ml"
               : 'annotation))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 272 "c/clparser.mly"
                    ( _1 )
# 2007 "c/clparser.ml"
               : 'ghost_lvalue))
; (fun __caml_parser_env ->
    Obj.repr(
# 276 "c/clparser.mly"
                ( None )
# 2013 "c/clparser.ml"
               : 'effects))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'locations) in
    Obj.repr(
# 277 "c/clparser.mly"
                    ( Some _2 )
# 2020 "c/clparser.ml"
               : 'effects))
; (fun __caml_parser_env ->
    Obj.repr(
# 278 "c/clparser.mly"
                  ( Some [] )
# 2026 "c/clparser.ml"
               : 'effects))
; (fun __caml_parser_env ->
    Obj.repr(
# 282 "c/clparser.mly"
                ( None )
# 2032 "c/clparser.ml"
               : 'loop_effects))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'ne_loop_effects) in
    Obj.repr(
# 283 "c/clparser.mly"
                  ( Some _1 )
# 2039 "c/clparser.ml"
               : 'loop_effects))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'locations) in
    Obj.repr(
# 287 "c/clparser.mly"
                         ( _2 )
# 2046 "c/clparser.ml"
               : 'ne_loop_effects))
; (fun __caml_parser_env ->
    Obj.repr(
# 288 "c/clparser.mly"
                       ( [] )
# 2052 "c/clparser.ml"
               : 'ne_loop_effects))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'location) in
    Obj.repr(
# 292 "c/clparser.mly"
           ( [_1] )
# 2059 "c/clparser.ml"
               : 'locations))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'location) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'locations) in
    Obj.repr(
# 293 "c/clparser.mly"
                           ( _1 :: _3 )
# 2067 "c/clparser.ml"
               : 'locations))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 297 "c/clparser.mly"
        ( _1 )
# 2074 "c/clparser.ml"
               : 'location))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'logic_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'parameters) in
    Obj.repr(
# 302 "c/clparser.mly"
    ( LDlogic (Info.default_logic_info _3, _2, _5, []) )
# 2083 "c/clparser.ml"
               : 'decl))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 6 : 'logic_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 5 : string) in
    let _5 = (Parsing.peek_val __caml_parser_env 3 : 'parameters) in
    let _8 = (Parsing.peek_val __caml_parser_env 0 : 'locations) in
    Obj.repr(
# 304 "c/clparser.mly"
    ( LDlogic (Info.default_logic_info _3, _2, _5, _8) )
# 2093 "c/clparser.ml"
               : 'decl))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 7 : 'logic_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _5 = (Parsing.peek_val __caml_parser_env 4 : 'parameters) in
    let _8 = (Parsing.peek_val __caml_parser_env 1 : 'lexpr) in
    Obj.repr(
# 306 "c/clparser.mly"
    ( LDlogic_def (Info.default_logic_info _3, _2, _5, _8) )
# 2103 "c/clparser.ml"
               : 'decl))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'parameters) in
    Obj.repr(
# 308 "c/clparser.mly"
    ( LDpredicate_reads (Info.default_logic_info _2, _4, []) )
# 2111 "c/clparser.ml"
               : 'decl))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 5 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'parameters) in
    let _7 = (Parsing.peek_val __caml_parser_env 0 : 'locations) in
    Obj.repr(
# 310 "c/clparser.mly"
    ( LDpredicate_reads (Info.default_logic_info _2, _4, _7) )
# 2120 "c/clparser.ml"
               : 'decl))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 4 : 'parameters) in
    let _7 = (Parsing.peek_val __caml_parser_env 1 : 'lexpr) in
    Obj.repr(
# 312 "c/clparser.mly"
    ( LDpredicate_def (Info.default_logic_info _2, _4, _7) )
# 2129 "c/clparser.ml"
               : 'decl))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 313 "c/clparser.mly"
                               ( LDaxiom (_2, _4) )
# 2137 "c/clparser.ml"
               : 'decl))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 314 "c/clparser.mly"
                                   ( LDinvariant (_2, _4) )
# 2145 "c/clparser.ml"
               : 'decl))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 315 "c/clparser.mly"
                  ( LDtype (_2, loc_i 2) )
# 2152 "c/clparser.ml"
               : 'decl))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'type_specifier) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'init_declarator_list) in
    Obj.repr(
# 320 "c/clparser.mly"
      ( List.map (ghost _2) _3 )
# 2160 "c/clparser.ml"
               : 'ghost_decl))
; (fun __caml_parser_env ->
    Obj.repr(
# 324 "c/clparser.mly"
       ( Cast_misc.noattr (CTint (Unsigned, Char)) )
# 2166 "c/clparser.ml"
               : 'type_specifier))
; (fun __caml_parser_env ->
    Obj.repr(
# 325 "c/clparser.mly"
      ( Cast_misc.noattr (CTint (Signed, Int)) )
# 2172 "c/clparser.ml"
               : 'type_specifier))
; (fun __caml_parser_env ->
    Obj.repr(
# 326 "c/clparser.mly"
        ( Cast_misc.noattr (CTfloat Float) )
# 2178 "c/clparser.ml"
               : 'type_specifier))
; (fun __caml_parser_env ->
    Obj.repr(
# 327 "c/clparser.mly"
         ( Cast_misc.noattr (CTfloat Double) )
# 2184 "c/clparser.ml"
               : 'type_specifier))
; (fun __caml_parser_env ->
    Obj.repr(
# 331 "c/clparser.mly"
                 ( [] )
# 2190 "c/clparser.ml"
               : 'parameters))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'ne_parameters) in
    Obj.repr(
# 332 "c/clparser.mly"
                ( _1 )
# 2197 "c/clparser.ml"
               : 'parameters))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'parameter) in
    Obj.repr(
# 336 "c/clparser.mly"
            ( [_1] )
# 2204 "c/clparser.ml"
               : 'ne_parameters))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'parameter) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'ne_parameters) in
    Obj.repr(
# 337 "c/clparser.mly"
                                ( _1 :: _3 )
# 2212 "c/clparser.ml"
               : 'ne_parameters))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'logic_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 341 "c/clparser.mly"
                        ( (_1, _2) )
# 2220 "c/clparser.ml"
               : 'parameter))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'logic_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : string) in
    Obj.repr(
# 342 "c/clparser.mly"
                                        ( (LTarray _1, _2) )
# 2228 "c/clparser.ml"
               : 'parameter))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'init_declarator) in
    Obj.repr(
# 349 "c/clparser.mly"
                          ( [_1] )
# 2235 "c/clparser.ml"
               : 'init_declarator_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'init_declarator_list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'init_declarator) in
    Obj.repr(
# 350 "c/clparser.mly"
                                                     ( _1 @ [_3] )
# 2243 "c/clparser.ml"
               : 'init_declarator_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'declarator) in
    Obj.repr(
# 355 "c/clparser.mly"
            ( let (id,d) = _1 in (id,d, None) )
# 2250 "c/clparser.ml"
               : 'init_declarator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'declarator) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'c_initializer) in
    Obj.repr(
# 357 "c/clparser.mly"
     ( let (id,d) = _1 in (id,d, Some _3) )
# 2258 "c/clparser.ml"
               : 'init_declarator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'direct_declarator) in
    Obj.repr(
# 362 "c/clparser.mly"
                              ( _1 )
# 2265 "c/clparser.ml"
               : 'declarator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 367 "c/clparser.mly"
            ( _1, Dsimple )
# 2272 "c/clparser.ml"
               : 'direct_declarator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'direct_declarator) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'lexpr) in
    Obj.repr(
# 369 "c/clparser.mly"
     ( let id,d = _1 in id, Darray (d, Some _3) )
# 2280 "c/clparser.ml"
               : 'direct_declarator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'direct_declarator) in
    Obj.repr(
# 371 "c/clparser.mly"
     ( let id,d = _1 in id, Darray (d, None) )
# 2287 "c/clparser.ml"
               : 'direct_declarator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'lexpr) in
    Obj.repr(
# 375 "c/clparser.mly"
                ( Iexpr _1 )
# 2294 "c/clparser.ml"
               : 'c_initializer))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'c_initializer_list) in
    Obj.repr(
# 376 "c/clparser.mly"
                                           ( Ilist _2 )
# 2301 "c/clparser.ml"
               : 'c_initializer))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'c_initializer_list) in
    Obj.repr(
# 377 "c/clparser.mly"
                                                 ( Ilist _2 )
# 2308 "c/clparser.ml"
               : 'c_initializer))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'c_initializer) in
    Obj.repr(
# 381 "c/clparser.mly"
                        ( [_1] )
# 2315 "c/clparser.ml"
               : 'c_initializer_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'c_initializer_list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'c_initializer) in
    Obj.repr(
# 382 "c/clparser.mly"
                                                 ( _1 @ [_3] )
# 2323 "c/clparser.ml"
               : 'c_initializer_list))
(* Entry annot *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
|]
let yytables =
  { Parsing.actions=yyact;
    Parsing.transl_const=yytransl_const;
    Parsing.transl_block=yytransl_block;
    Parsing.lhs=yylhs;
    Parsing.len=yylen;
    Parsing.defred=yydefred;
    Parsing.dgoto=yydgoto;
    Parsing.sindex=yysindex;
    Parsing.rindex=yyrindex;
    Parsing.gindex=yygindex;
    Parsing.tablesize=yytablesize;
    Parsing.table=yytable;
    Parsing.check=yycheck;
    Parsing.error_function=parse_error;
    Parsing.names_const=yynames_const;
    Parsing.names_block=yynames_block }
let annot (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 1 lexfun lexbuf : Cast.parsed_annot)
;;
